@@ -16,11 +16,32 @@
 '''
 import collections
 
-from pm4py.algo.discovery.transition_system.parameters import Parameters
 from pm4py.util import exec_utils
 from pm4py.objects.log import util as log_util
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
-from pm4py.objects.transition_system import transition_system as ts, constants as ts_constants
+from pm4py.objects.transition_system import obj as ts, constants as ts_constants
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    VIEW_MULTI_SET = 'multiset'
+    VIEW_SET = 'set'
+    VIEW_SEQUENCE = 'sequence'
+
+    VIEWS = {VIEW_MULTI_SET, VIEW_SET, VIEW_SEQUENCE}
+
+    DIRECTION_FORWARD = 'forward'
+    DIRECTION_BACKWARD = 'backward'
+    DIRECTIONS = {DIRECTION_FORWARD, DIRECTION_BACKWARD}
+
+    PARAM_KEY_VIEW = 'view'
+    PARAM_KEY_WINDOW = 'window'
+    PARAM_KEY_DIRECTION = 'direction'
+
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+
+    INCLUDE_DATA = 'include_data'
 
 
 def apply(log, parameters=None):
