@@ -21,7 +21,7 @@ import deprecation
 import pandas as pd
 
 from pm4py.meta import VERSION as PM4PY_CURRENT_VERSION
-from pm4py.objects.log.log import EventLog
+from pm4py.objects.log.obj import EventLog
 from pm4py.util import constants
 from pm4py.util.pandas_utils import check_is_dataframe, check_dataframe_columns
 
@@ -88,7 +88,7 @@ def filter_end_activities(log: Union[EventLog, pd.DataFrame], activities: List[s
                                            parameters={end_activities_filter.Parameters.POSITIVE: retain})
 
 
-@deprecation.deprecated(deprecated_in='2.1.4', removed_in='2.3.0', current_version=PM4PY_CURRENT_VERSION,
+@deprecation.deprecated(deprecated_in='2.1.4', removed_in='2.4.0', current_version=PM4PY_CURRENT_VERSION,
                         details='Filtering method will be removed due to fuzzy naming.\
                         Use: filter_event_attribute_values')
 def filter_attribute_values(log, attribute_key, values, level="case", retain=True):
@@ -142,7 +142,7 @@ def filter_event_attribute_values(log: Union[EventLog, pd.DataFrame], attribute_
                 attributes_filter.Parameters.POSITIVE: retain})
 
 
-@deprecation.deprecated(deprecated_in='2.1.4', removed_in='2.3.0', current_version=PM4PY_CURRENT_VERSION,
+@deprecation.deprecated(deprecated_in='2.1.4', removed_in='2.4.0', current_version=PM4PY_CURRENT_VERSION,
                         details='Filtering method will be removed due to fuzzy naming.\
                         Use: filter_event_attribute_values')
 def filter_trace_attribute(log, attribute_key, values, retain=True):
@@ -212,7 +212,7 @@ def filter_variants(log: Union[EventLog, pd.DataFrame], variants: List[List[str]
                                      parameters={variants_filter.Parameters.POSITIVE: retain})
 
 
-@deprecation.deprecated(deprecated_in='2.1.3.1', removed_in='2.3.0', current_version=PM4PY_CURRENT_VERSION,
+@deprecation.deprecated(deprecated_in='2.1.3.1', removed_in='2.4.0', current_version=PM4PY_CURRENT_VERSION,
                         details='Filtering method will be removed due to fuzzy interpretation of the threshold.\
                         Will be replaced with two new functions filter_variants_top_k and filter_variants_relative_frequency')
 def filter_variants_percentage(log: Union[EventLog, pd.DataFrame], threshold: float = 0.8) -> Union[
@@ -240,7 +240,7 @@ def filter_variants_percentage(log: Union[EventLog, pd.DataFrame], threshold: fl
         return variants_filter.filter_log_variants_percentage(log, percentage=threshold)
 
 
-@deprecation.deprecated(deprecated_in='2.1.3.1', removed_in='2.3.0', current_version=PM4PY_CURRENT_VERSION,
+@deprecation.deprecated(deprecated_in='2.1.3.1', removed_in='2.4.0', current_version=PM4PY_CURRENT_VERSION,
                         details='Use filter_directly_follows_relation')
 def filter_paths(log, allowed_paths, retain=True):
     return filter_directly_follows_relation(log, allowed_paths, retain)
@@ -305,7 +305,7 @@ def filter_eventually_follows_relation(log: Union[EventLog, pd.DataFrame], relat
         else:
             cases = set(log[constants.CASE_CONCEPT_NAME])
         for path in relations:
-            filt_log = ltl_checker.A_eventually_B(log, path[0], path[1],
+            filt_log = ltl_checker.eventually_follows(log, path,
                                                   parameters={ltl_checker.Parameters.POSITIVE: retain})
             this_traces = set(filt_log[constants.CASE_CONCEPT_NAME])
             if retain:
@@ -314,14 +314,14 @@ def filter_eventually_follows_relation(log: Union[EventLog, pd.DataFrame], relat
                 cases = cases.intersection(this_traces)
         return log[log[constants.CASE_CONCEPT_NAME].isin(cases)]
     else:
-        from pm4py.objects.log.log import EventLog
+        from pm4py.objects.log.obj import EventLog
         from pm4py.algo.filtering.log.ltl import ltl_checker
         if retain:
             cases = set()
         else:
             cases = set(id(trace) for trace in log)
         for path in relations:
-            filt_log = ltl_checker.A_eventually_B(log, path[0], path[1],
+            filt_log = ltl_checker.eventually_follows(log, path,
                                                   parameters={ltl_checker.Parameters.POSITIVE: retain})
             this_traces = set(id(trace) for trace in filt_log)
             if retain:
