@@ -16,7 +16,7 @@
 '''
 from enum import Enum
 
-from pm4py.objects.dfg.retrieval.pandas import get_partial_order_dataframe
+from pm4py.algo.discovery.dfg.adapters.pandas.df_statistics import get_partial_order_dataframe
 from pm4py.util import exec_utils, constants, xes_constants
 
 
