@@ -17,6 +17,10 @@
 from enum import Enum
 from pm4py.util import constants
 
+import warnings
+
+warnings.warn("pm4py.statistics.performance_spectrum.parameters is deprecated. please use the variant-specific parameters")
+
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
@@ -24,4 +28,3 @@ class Parameters(Enum):
     CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
     ATTRIBUTE_KEY = constants.PARAMETER_CONSTANT_ATTRIBUTE_KEY
     PARAMETER_SAMPLE_SIZE = "sample_size"
-
