@@ -15,10 +15,11 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from typing import Dict, Union, List, Tuple
+from typing import Set
 
 import pandas as pd
 
-from pm4py.objects.log.log import EventLog, Trace
+from pm4py.objects.log.obj import EventLog, Trace
 from pm4py.util.pandas_utils import check_is_dataframe, check_dataframe_columns
 
 
@@ -138,6 +139,31 @@ def get_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: str) ->
         return get.get_attribute_values(log, attribute)
 
 
+def get_trace_attribute_values(log: Union[EventLog, pd.DataFrame], attribute: str) -> Dict[str, int]:
+    """
+    Returns the values for a specified trace attribute
+
+    Parameters
+    ---------------
+    log
+        Log object
+    attribute
+        Attribute
+
+    Returns
+    ---------------
+    attribute_values
+        Dictionary of values along with their count
+    """
+    if check_is_dataframe(log):
+        check_dataframe_columns(log)
+        from pm4py.statistics.attributes.pandas import get
+        return get.get_attribute_values(log, attribute)
+    else:
+        from pm4py.statistics.attributes.log import get
+        return get.get_trace_attribute_values(log, attribute)
+
+
 def get_variants(log: Union[EventLog, pd.DataFrame]) -> Dict[str, List[Trace]]:
     """
     Gets the variants from the log
@@ -192,3 +218,69 @@ def get_variants_as_tuples(log: Union[EventLog, pd.DataFrame]) -> Dict[Tuple[str
     else:
         from pm4py.statistics.variants.log import get
         return get.get_variants(log)
+
+
+def get_minimum_self_distances(log: EventLog) -> Dict[str, int]:
+    '''
+    This algorithm computes the minimum self-distance for each activity observed in an event log.
+    The self distance of a in <a> is infinity, of a in <a,a> is 0, in <a,b,a> is 1, etc.
+    The minimum self distance is the minimal observed self distance value in the event log.
+
+    Parameters
+    ----------
+    log
+        event log (either pandas.DataFrame, EventLog or EventStream)
+
+    Returns
+    -------
+        dict mapping an activity to its self-distance, if it exists, otherwise it is not part of the dict.
+    '''
+    from pm4py.algo.discovery.minimum_self_distance import algorithm as msd_algo
+    return msd_algo.apply(log)
+
+
+def get_minimum_self_distance_witnesses(log: EventLog) -> Dict[str, Set[str]]:
+    '''
+        This function derives the minimum self distance witnesses.
+        The self distance of a in <a> is infinity, of a in <a,a> is 0, in <a,b,a> is 1, etc.
+        The minimum self distance is the minimal observed self distance value in the event log.
+        A 'witness' is an activity that witnesses the minimum self distance.
+        For example, if the minimum self distance of activity a in some log L is 2, then,
+        if trace <a,b,c,a> is in log L, b and c are a witness of a.
+
+        Parameters
+        ----------
+        log
+            Event Log to use
+
+        Returns
+        -------
+        Dictionary mapping each activity to a set of witnesses.
+
+        '''
+    from pm4py.algo.discovery.minimum_self_distance import algorithm as msd_algo
+    from pm4py.algo.discovery.minimum_self_distance import utils as msdw_algo
+    return msdw_algo.derive_msd_witnesses(log, msd_algo.apply(log))
+
+
+def get_case_arrival_average(log: Union[EventLog, pd.DataFrame]) -> float:
+    """
+    Gets the average difference between the start times of two consecutive cases
+
+    Parameters
+    ---------------
+    log
+        Log object
+
+    Returns
+    ---------------
+    case_arrival_average
+        Average difference between the start times of two consecutive cases
+    """
+    if check_is_dataframe(log):
+        check_dataframe_columns(log)
+        from pm4py.statistics.traces.pandas import case_arrival
+        return case_arrival.get_case_arrival_avg(log)
+    else:
+        from pm4py.statistics.traces.log import case_arrival
+        return case_arrival.get_case_arrival_avg(log)
