@@ -18,8 +18,8 @@ import pkgutil
 
 if pkgutil.find_loader("graphviz"):
     # imports the visualizations only if graphviz is installed
-    from pm4py.visualization import common, dfg, petrinet, process_tree, transition_system, decisiontree, align_table, \
-        footprints, bpmn
+    from pm4py.visualization import common, dfg, petri_net, process_tree, transition_system, decisiontree, align_table, \
+        footprints, bpmn, trie
     if pkgutil.find_loader("matplotlib") and pkgutil.find_loader("pyvis"):
         # SNA requires both packages matplotlib and pyvis. These are included in the default installation;
         # however, they may lead to problems in some platforms/deployments
