@@ -19,7 +19,16 @@ from copy import copy
 
 from graphviz import Digraph
 from pm4py.util import exec_utils
-from pm4py.visualization.transition_system.parameters import Parameters
+from enum import Enum
+
+
+class Parameters(Enum):
+    FORMAT = "format"
+    SHOW_LABELS = "show_labels"
+    SHOW_NAMES = "show_names"
+    FORCE_NAMES = "force_names"
+    FILLCOLORS = "fillcolors"
+    FONT_SIZE = "font_size"
 
 
 def visualize(ts, parameters=None):
@@ -31,6 +40,8 @@ def visualize(ts, parameters=None):
     show_names = exec_utils.get_param_value(Parameters.SHOW_NAMES, parameters, True)
     force_names = exec_utils.get_param_value(Parameters.FORCE_NAMES, parameters, None)
     fillcolors = exec_utils.get_param_value(Parameters.FILLCOLORS, parameters, {})
+    font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 11)
+    font_size = str(font_size)
 
     for state in ts.states:
         state.label = state.name
@@ -53,23 +64,22 @@ def visualize(ts, parameters=None):
     for s in ts.states:
         if show_names:
             if s in fillcolors:
-                viz.node(str(id(s)), str(s.label), style="filled", fillcolor=fillcolors[s])
+                viz.node(str(id(s)), str(s.label), style="filled", fillcolor=fillcolors[s], fontsize=font_size)
             else:
-                viz.node(str(id(s)), str(s.label))
+                viz.node(str(id(s)), str(s.label), fontsize=font_size)
         else:
             if s in fillcolors:
-                viz.node(str(id(s)), "", style="filled", fillcolor=fillcolors[s])
+                viz.node(str(id(s)), "", style="filled", fillcolor=fillcolors[s], fontsize=font_size)
             else:
-                viz.node(str(id(s)), "")
+                viz.node(str(id(s)), "", fontsize=font_size)
     # arcs
     for t in ts.transitions:
         if show_labels:
-            viz.edge(str(id(t.from_state)), str(id(t.to_state)), label=t.name)
+            viz.edge(str(id(t.from_state)), str(id(t.to_state)), label=t.name, fontsize=font_size)
         else:
             viz.edge(str(id(t.from_state)), str(id(t.to_state)))
 
     viz.attr(overlap='false')
-    viz.attr(fontsize='11')
 
     viz.format = image_format
 
